@@ -11,7 +11,8 @@ Sigma<-Sigma*phi
 D<-as.vector(family$mu.eta(Eta))
 
 if(print.iter.final)
-print(paste("Final Re-estimation Iteration ", 1,sep=""))
+  message("Final Re-estimation Iteration ", 1)
+#print(paste("Final Re-estimation Iteration ", 1,sep=""))
 
 
 Z_alles<-cbind(X,W)
@@ -175,7 +176,8 @@ for (l in 2:steps)
 {
   
 if(print.iter.final)
-print(paste("Final Re-estimation Iteration ", l,sep=""))
+  message("Final Re-estimation Iteration ", l)
+#print(paste("Final Re-estimation Iteration ", l,sep=""))
 
 half.index<-0
 solve.test<-FALSE
